# -*- coding: utf-8 -*-
from pyramid_oereb.standard.xtf_import.util import parse_string, parse_multilingual_text, parse_ref


class Article(object):

    TAG_TEXT_AT_WEB = 'TextImWeb'
    TAG_LAW_STATUS = 'Rechtsstatus'
    TAG_PUBLISHED_FROM = 'publiziertAb'
    TAG_NUMBER = 'Nr'
    TAG_TEXT = 'Text'
    TAG_DOCUMENT = 'Dokument'

    def __init__(self, session, model):
        self._session = session
        self._model = model

    def parse(self, article):  # pragma: no cover
        instance = self._model(
            id=article.attrib['TID'],
            text_at_web=parse_multilingual_text(article, self.TAG_TEXT_AT_WEB),
            law_status=parse_string(article, self.TAG_LAW_STATUS),
            published_from=parse_string(article, self.TAG_PUBLISHED_FROM),
            number=parse_string(article, self.TAG_NUMBER),
            text=parse_multilingual_text(article, self.TAG_TEXT),
            document_id=parse_ref(article, self.TAG_DOCUMENT)
        )
        self._session.add(instance)



# -*- coding: utf-8 -*-
from pyramid_oereb.lib.sources import BaseDatabaseSource
from pyramid_oereb.lib.records.view_service import LegendEntryRecord
from pyramid_oereb.lib.sources.legend import LegendBaseSource


class DatabaseSource(BaseDatabaseSource, LegendBaseSource):

    def read(self, **kwargs):
        """
        Central method to read one legend entry.

        Args:
            (kwargs): Arbitrary keyword arguments. It must contain the key 'type_code'.
        """
        session = self._adapter_.get_session(self._key_)
        try:
            query = session.query(self._model_)
            if kwargs.get('type_code'):
                results = query.filter(
                    self._model_.type_code == kwargs.get('type_code')
                ).all()
            else:
                raise AttributeError('Necessary parameter is missing.')

            self.records = list()
            for result in results:
                self.records.append(LegendEntryRecord(
                    result.symbol,
                    result.legend_text,
                    result.type_code,
                    result.type_code_list,
                    result.theme
                ))
        finally:
            session.close()
